==> redisson-3.25.0-sources.jar: org/redisson/api/queue/DequeMoveParams.java <==
/**
 * Copyright (c) 2013-2022 Nikita Koksharov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.redisson.api.queue;

/**
 *
 * @author Nikita Koksharov
 *
 */
public class DequeMoveParams implements DequeMoveDestination {

    public enum Direction {LEFT, RIGHT};

    private Direction sourceDirection;
    private Direction destDirection;
    private String destName;

    DequeMoveParams(Direction direction) {
        sourceDirection = direction;
    }

    @Override
    public DequeMoveArgs addFirstTo(String name) {
        destDirection = Direction.LEFT;
        destName = name;
        return this;
    }

    @Override
    public DequeMoveArgs addLastTo(String name) {
        destDirection = Direction.RIGHT;
        destName = name;
        return this;
    }

    public Direction getSourceDirection() {
        return sourceDirection;
    }

    public Direction getDestDirection() {
        return destDirection;
    }

    public String getDestName() {
        return destName;
    }
}

==> redisson-3.25.2-sources.jar: org/redisson/api/queue/DequeMoveParams.java <==
/**
 * Copyright (c) 2013-2022 Nikita Koksharov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.redisson.api.queue;

/**
 *
 * @author Nikita Koksharov
 *
 */
public class DequeMoveParams implements DequeMoveDestination {

    public enum Direction {LEFT, RIGHT};

    private final Direction sourceDirection;
    private Direction destDirection;
    private String destName;

    DequeMoveParams(Direction direction) {
        sourceDirection = direction;
    }

    @Override
    public DequeMoveArgs addFirstTo(String name) {
        destDirection = Direction.LEFT;
        destName = name;
        return this;
    }

    @Override
    public DequeMoveArgs addLastTo(String name) {
        destDirection = Direction.RIGHT;
        destName = name;
        return this;
    }

    public Direction getSourceDirection() {
        return sourceDirection;
    }

    public Direction getDestDirection() {
        return destDirection;
    }

    public String getDestName() {
        return destName;
    }
}
